@@ -1,3 +1,4 @@
+from logging import Logger
 from magic_admin import Magic
 from pyvise.base import get_logger, get_setting
 from pyvise.models import User
@@ -27,6 +28,7 @@ def find_magic_user(email_address: str, did_token: str) -> User:
         else:
             return None
     except Exception as exc:
-        print(f"Exception thrown, suppressing and returning False {exc}")
+        message = f"backend.magic_backend: Magic API threw an exception.  It's likely an invalid user"
+        Logger.exception(message, exc)
         # logger.exception("Could not validate did token", exc)
     return None
